==> carbon-component-mapper-3.13.0.tgz: package/esm/time-picker-string/time-picker-string.js <==
import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "meta", "twelveHoursFormat", "timezones", "validateOnMount", "helperText", "WrapperProps", "useStringFormat"];
import React, { useState, useEffect, useRef } from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import prepareProps from '../prepare-props';
import TimePickerBase from '../time-picker-base';

var TimePickerString = function TimePickerString(props) {
  var _useFieldApi = useFieldApi(prepareProps(props)),
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      twelveHoursFormat = _useFieldApi.twelveHoursFormat,
      timezones = _useFieldApi.timezones,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      WrapperProps = _useFieldApi.WrapperProps,
      useStringFormat = _useFieldApi.useStringFormat,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var _useState = useState(function () {
    var _input$value$match, _timezones$;

    return timezones ? ((_input$value$match = input.value.match(/ \w+$/)) === null || _input$value$match === void 0 ? void 0 : _input$value$match[0].trim()) || ((_timezones$ = timezones[0]) === null || _timezones$ === void 0 ? void 0 : _timezones$.value) : '';
  }),
      _useState2 = _slicedToArray(_useState, 2),
      timezone = _useState2[0],
      selectTimezone = _useState2[1];

  var _useState3 = useState(function () {
    var _input$value$match2;

    return ((_input$value$match2 = input.value.match(/ \w+ /)) === null || _input$value$match2 === void 0 ? void 0 : _input$value$match2[0].trim()) || 'AM';
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      format = _useState4[0],
      selectFormat = _useState4[1];

  var isMounted = useRef(false);
  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;
  var finalValue = input.value.replace(/ .*/, '');

  var enhancedOnChange = function enhancedOnChange(value) {
    return input.onChange("".concat(value, " ").concat(twelveHoursFormat ? format : '', " ").concat(timezones ? timezone : '').replace(/ {2}/, ' ').trim());
  };

  useEffect(function () {
    if (isMounted.current === true) {
      enhancedOnChange(finalValue);
    } else {
      isMounted.current = true;
    }
  }, [timezone, format]);
  return /*#__PURE__*/React.createElement(TimePickerBase, _extends({
    WrapperProps: WrapperProps,
    input: input,
    enhancedOnChange: enhancedOnChange,
    finalValue: finalValue,
    invalid: invalid,
    twelveHoursFormat: twelveHoursFormat,
    timezones: timezones,
    helperText: helperText,
    warnText: warnText,
    selectFormat: selectFormat,
    selectTimezone: selectTimezone
  }, rest));
};

TimePickerString.propTypes = {
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  labelText: PropTypes.node,
  description: PropTypes.node,
  twelveHoursFormat: PropTypes.bool,
  timezones: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.string.isRequired,
    label: PropTypes.node.isRequired,
    showAs: PropTypes.string
  })),
  WrapperProps: PropTypes.object,
  useStringFormat: PropTypes.bool
};
export default TimePickerString;

==> carbon-component-mapper-3.17.0.tgz: package/esm/time-picker-string/time-picker-string.js <==
import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "meta", "twelveHoursFormat", "timezones", "validateOnMount", "helperText", "WrapperProps", "useStringFormat"];
import React, { useState, useEffect, useRef } from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import prepareProps from '../prepare-props';
import TimePickerBase from '../time-picker-base';

var TimePickerString = function TimePickerString(props) {
  var _useFieldApi = useFieldApi(prepareProps(props)),
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      twelveHoursFormat = _useFieldApi.twelveHoursFormat,
      timezones = _useFieldApi.timezones,
      validateOnMount = _useFieldApi.validateOnMount,
      helperText = _useFieldApi.helperText,
      WrapperProps = _useFieldApi.WrapperProps,
      useStringFormat = _useFieldApi.useStringFormat,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var _useState = useState(function () {
    var _input$value$match, _timezones$;

    return timezones ? ((_input$value$match = input.value.match(/ \w+$/)) === null || _input$value$match === void 0 ? void 0 : _input$value$match[0].trim()) || ((_timezones$ = timezones[0]) === null || _timezones$ === void 0 ? void 0 : _timezones$.value) : '';
  }),
      _useState2 = _slicedToArray(_useState, 2),
      timezone = _useState2[0],
      selectTimezone = _useState2[1];

  var _useState3 = useState(function () {
    var _input$value$match2;

    return ((_input$value$match2 = input.value.match(/ \w+ /)) === null || _input$value$match2 === void 0 ? void 0 : _input$value$match2[0].trim()) || 'AM';
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      format = _useState4[0],
      selectFormat = _useState4[1];

  var isMounted = useRef(false);
  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warnText = (meta.touched || validateOnMount) && meta.warning;
  var finalValue = input.value.replace(/ .*/, '');

  var enhancedOnChange = function enhancedOnChange(value) {
    return input.onChange("".concat(value, " ").concat(twelveHoursFormat ? format : '', " ").concat(timezones ? timezone : '').replace(/ {2}/, ' ').trim());
  };

  useEffect(function () {
    if (isMounted.current === true) {
      enhancedOnChange(finalValue);
    } else {
      isMounted.current = true;
    }
  }, [timezone, format]);
  return /*#__PURE__*/React.createElement(TimePickerBase, _extends({
    WrapperProps: WrapperProps,
    input: input,
    enhancedOnChange: enhancedOnChange,
    finalValue: finalValue,
    invalid: invalid,
    twelveHoursFormat: twelveHoursFormat,
    timezones: timezones,
    helperText: helperText,
    warnText: warnText,
    selectFormat: selectFormat,
    selectTimezone: selectTimezone,
    format: format,
    timezone: timezone
  }, rest));
};

TimePickerString.propTypes = {
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  labelText: PropTypes.node,
  description: PropTypes.node,
  twelveHoursFormat: PropTypes.bool,
  timezones: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.string.isRequired,
    label: PropTypes.node.isRequired,
    showAs: PropTypes.string
  })),
  WrapperProps: PropTypes.object,
  useStringFormat: PropTypes.bool
};
export default TimePickerString;
